/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
    Copyright 2000-2025 the Rosegarden development team.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef RG_REMOVEMARKERCOMMAND_H
#define RG_REMOVEMARKERCOMMAND_H

#include "document/Command.h"

#include <QCoreApplication>
#include <QString>

#include <string>


namespace Rosegarden
{


class Marker;
class Composition;


class RemoveMarkerCommand : public NamedCommand
{
    Q_DECLARE_TR_FUNCTIONS(Rosegarden::RemoveMarkerCommand)

public:
    RemoveMarkerCommand(Composition *comp, int markerID);
    ~RemoveMarkerCommand() override;

    static QString getGlobalName()  { return tr("&Remove Marker"); }

    void execute() override;
    void unexecute() override;

private:

    Composition *m_composition;
    int m_markerID;

    Marker *m_marker{nullptr};
    // Indicates that m_marker is no longer attached to the Composition and
    // must be destroyed in the ctor.
    bool m_detached{false};

};


}

#endif
